==> elasticsearch-java-7.17.29-sources.jar: co/elastic/clients/transport/endpoints/BooleanEndpoint.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package co.elastic.clients.transport.endpoints;

import java.util.Map;
import java.util.function.Function;

public class BooleanEndpoint<RequestT> extends EndpointBase<RequestT, BooleanResponse> {

    public BooleanEndpoint(
        String id,
        Function<RequestT, String> method,
        Function<RequestT, String> requestUrl,
        Function<RequestT,
            Map<String, String>> queryParameters,
        Function<RequestT, Map<String, String>> headers,
        boolean hasRequestBody,
        Object ignored // same number of arguments as SimpleEndpoint
    ) {
        super(id, method, requestUrl, queryParameters, headers, hasRequestBody ? returnSelf() : returnNull());
    }

    @Override
    public boolean isError(int statusCode) {
        // 404 indicates a 'false' result.
        return statusCode != 404 && super.isError(statusCode);
    }

    public boolean getResult(int statusCode) {
        return statusCode < 400;
    }
}

==> elasticsearch-java-8.4.1-sources.jar: co/elastic/clients/transport/endpoints/BooleanEndpoint.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package co.elastic.clients.transport.endpoints;

import co.elastic.clients.json.JsonpDeserializer;

import java.util.Map;
import java.util.function.Function;

public class BooleanEndpoint<RequestT> extends SimpleEndpoint<RequestT, BooleanResponse> {

    public BooleanEndpoint(
        String id,
        Function<RequestT, String> method,
        Function<RequestT, String> requestUrl,
        Function<RequestT,
            Map<String, String>> queryParameters,
        Function<RequestT, Map<String, String>> headers,
        boolean hasRequestBody,
        JsonpDeserializer<?> responseParser // always null
    ) {
        super(id, method, requestUrl, queryParameters, headers, hasRequestBody, null);
    }

    @Override
    public boolean isError(int statusCode) {
        return statusCode >= 500;
    }

    public boolean getResult(int statusCode) {
        return statusCode < 400;
    }
}
